.. python_secrets documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. meta::
   :description: Python CLI for managing secrets in open source code projects
   :robots: index, follow
   :keywords: python, secrets, python_secrets, psec


psec
====

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   advanced
   reference
   contributing
   authors
   history
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

